import requests as requests_http
from . import utils
from airbyte.models import operations

class Connections:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def reset_connection(self, request: operations.ResetConnectionRequest) -> operations.ResetConnectionResponse:
        r"""Reset the data for the connection.
        Reset the data for the connection. Deletes data generated by the connection in the destination. Resets any cursors back to initial state.
        """
        
        base_url = self._server_url
        
        url = utils.generate_url(base_url, '/v1/connections/{connectionId}/reset', request.path_params)
        
        
        client = self._client
        
        http_res = client.request('POST', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ResetConnectionResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            pass
        elif http_res.status_code == 403:
            pass
        elif http_res.status_code == 404:
            pass

        return res

    def sync_connection(self, request: operations.SyncConnectionRequest) -> operations.SyncConnectionResponse:
        r"""Trigger a manual sync of the connection
        """
        
        base_url = self._server_url
        
        url = utils.generate_url(base_url, '/v1/connections/{connectionId}/sync', request.path_params)
        
        
        client = self._client
        
        http_res = client.request('POST', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.SyncConnectionResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            pass
        elif http_res.status_code == 403:
            pass
        elif http_res.status_code == 404:
            pass

        return res

    